

## QA Tools

Project must be built and tested using:

- [ ] the recommended good principles of Software Quality Assurance (SQA).
- [ ] coverage over 90%.
- [ ] random inputs on test cases.
- [ ] try to break the code using tricky inputs.
- [ ] try to break the code using fuzzing techniques.
- [ ] selective and random testing for statistical analysis.
- [ ] execution of all test cases as well (100% existing test cases).
